@@ -15,7 +15,7 @@ impl<M> StatementAble<M> for Order<M> where M: ModelAble {
     fn json_value(&self) -> Option<&Json> {
         Some(&self.value)
     }
-    fn to_sql_literals(&self) -> Vec<SqlLiteral> {
+    fn to_sql_literals(&self) -> anyhow::Result<Vec<SqlLiteral>> {
         let mut vec = vec![];
         if let Some(json_value) = self.json_value() {
             match json_value {
@@ -23,7 +23,7 @@ impl<M> StatementAble<M> for Order<M> where M: ModelAble {
                     for column_name in json_object.keys() {
                         let table_column_name = methods::table_column_name::<M>(column_name);
                         let json_value = json_object.get(column_name).unwrap();
-                        vec.push(SqlLiteral::new(format!("{} {}", table_column_name, self.json_value_sql(json_value).to_uppercase())));
+                        vec.push(SqlLiteral::new(format!("{} {}", table_column_name, self.json_value_sql(json_value)?.to_uppercase())));
                     }
                 },
                 Json::Array(json_array) => {
@@ -31,23 +31,23 @@ impl<M> StatementAble<M> for Order<M> where M: ModelAble {
                         if let Json::String(json_string) = column_name {
                             vec.push(SqlLiteral::new(format!("{}", json_string)));
                         } else {
-                            panic!("Error: Not Support");
+                            return Err(anyhow::anyhow!("Error: {:?} Not Support", self.json_value()))
                         }
                     }
                 },
-                _ =>  vec.append(&mut StatementAble::to_sql_literals_default(self)),
+                _ =>  vec.append(&mut StatementAble::to_sql_literals_default(self)?),
             }
         }
         // Ok(vec.join(" AND "))
-        vec
+        Ok(vec)
     }
-    fn to_sql(&self) -> String {
-        format!("{}", self.to_sql_with_concat(", "))
+    fn to_sql(&self) -> anyhow::Result<String> {
+        Ok(format!("{}", self.to_sql_with_concat(", ")?))
     }
-    fn json_value_sql(&self, json_value: &Json) -> String {
+    fn json_value_sql(&self, json_value: &Json) -> anyhow::Result<String> {
         match json_value {
             Json::String(json_string) => {
-                format!("{}", json_string)
+                Ok(format!("{}", json_string))
             },
             _ => StatementAble::json_value_sql_default(self, json_value)
         }
@@ -74,14 +74,14 @@ mod tests {
         impl ModelAble for User {}
 
         let order = Order::<User>::new(json!("name desc"));
-        assert_eq!(order.to_sql(), "name desc");
+        assert_eq!(order.to_sql().unwrap(), "name desc");
 
         let order = Order::<User>::new(json!(["name desc", "age asc"]));
-        assert_eq!(order.to_sql(), "name desc, age asc");
+        assert_eq!(order.to_sql().unwrap(), "name desc, age asc");
         let order = Order::<User>::new(json!({
             "name": "desc",
             "age": "asc"
         }));
-        assert_eq!(order.to_sql(), "`users`.`age` ASC, `users`.`name` DESC");
+        assert_eq!(order.to_sql().unwrap(), "`users`.`age` ASC, `users`.`name` DESC");
     }
 }
