@@ -38,7 +38,7 @@ impl<M> StatementAble<M> for Where<M> where M: ModelAble {
     fn json_value(&self) -> Option<&Json> {
         Some(&self.value)
     }
-    fn to_sql_literals(&self) -> Vec<SqlLiteral> {
+    fn to_sql_literals(&self) -> anyhow::Result<Vec<SqlLiteral>> {
         let mut vec = vec![];
         if let Some(json_value) = self.json_value() {
             match json_value {
@@ -46,7 +46,7 @@ impl<M> StatementAble<M> for Where<M> where M: ModelAble {
                     for column_name in json_object.keys() {
                         let table_column_name = methods::table_column_name::<M>(column_name);
                         let json_value = json_object.get(column_name).unwrap();
-                        vec.push(SqlLiteral::new(format!("{} {}", table_column_name, self.json_value_sql(json_value, true))));
+                        vec.push(SqlLiteral::new(format!("{} {}", table_column_name, self.json_value_sql(json_value, true)?)));
                     }
                 },
                 _ => {
@@ -54,8 +54,8 @@ impl<M> StatementAble<M> for Where<M> where M: ModelAble {
                         match json_value {
                             // json([column_name, start, end])
                             Json::Array(json_array) if json_array.len() == 3 => {
-                                let table_column_name = methods::table_column_name::<M>(&self.json_value_sql(json_array.get(0).unwrap(), false));
-                                let between_sql = format!("BETWEEN {} AND {}", self.json_value_sql(json_array.get(1).unwrap(), false), self.json_value_sql(json_array.get(2).unwrap(), false));
+                                let table_column_name = methods::table_column_name::<M>(&self.json_value_sql(json_array.get(0).unwrap(), false)?);
+                                let between_sql = format!("BETWEEN {} AND {}", self.json_value_sql(json_array.get(1).unwrap(), false)?, self.json_value_sql(json_array.get(2).unwrap(), false)?);
                                 if self.ops.is_not {
                                     vec.push(SqlLiteral::new(format!("{} NOT {}", table_column_name, between_sql)));
                                 }
@@ -64,25 +64,25 @@ impl<M> StatementAble<M> for Where<M> where M: ModelAble {
                                 }
                             },
                             Json::String(_) => {
-                                vec.append(&mut StatementAble::to_sql_literals_default(self))
+                                vec.append(&mut StatementAble::to_sql_literals_default(self)?)
                             },
-                            _ => panic!("Error: Not Support")
+                            _ => return Err(anyhow::anyhow!("Error: {:?} Not Support", self.json_value()))
                         }
                     } else if self.ops.is_not {
-                        panic!("Error: Not Support")
+                        return Err(anyhow::anyhow!("Error: {:?} Not Support", self.json_value()))
                     } else {
-                        vec.append(&mut StatementAble::to_sql_literals_default(self))
+                        vec.append(&mut StatementAble::to_sql_literals_default(self)?)
                     }
                 },
             }
         }
         // Ok(vec.join(" AND "))
-        vec
+        Ok(vec)
     }
-    fn to_sql(&self) -> String {
+    fn to_sql(&self) -> anyhow::Result<String> {
         match self.ops.join_type {
-            JoinType::And => self.to_sql_with_concat(" AND "),
-            JoinType::Or => format!("({})", self.to_sql_with_concat(" OR "))
+            JoinType::And => Ok(self.to_sql_with_concat(" AND ")?),
+            JoinType::Or => Ok(format!("({})", self.to_sql_with_concat(" OR ")?))
         }
     }
 }
@@ -95,59 +95,59 @@ impl<M> Where<M> where M: ModelAble {
             _marker: PhantomData,
         }
     }
-    fn json_value_sql(&self, json_value: &Json, with_modifier: bool) -> String {
+    fn json_value_sql(&self, json_value: &Json, with_modifier: bool) -> anyhow::Result<String> {
         match json_value {
             Json::Array(json_array) => {
                 let mut values = vec![];
                 for json_value in json_array.iter() {
-                    values.push(self.json_value_sql(json_value, false));
+                    values.push(self.json_value_sql(json_value, false)?);
                 }
                 if self.ops.is_between {
                     if json_array.len() == 2 && with_modifier {
                         let between_sql = format!("BETWEEN {} AND {}", values.get(0).unwrap(), values.get(1).unwrap());
-                        if self.ops.is_not { format!("NOT {}", &between_sql) } else { format!("{}", &between_sql) }
+                        if self.ops.is_not { Ok(format!("NOT {}", &between_sql)) } else { Ok(format!("{}", &between_sql)) }
                     } else {
-                        panic!("Error: Not Support, Between statement Array must 2 length")
+                        return Err(anyhow::anyhow!("Error: {:?} Not Support, Between statement Array must 2 length", self.json_value()))
                     }
                 } else {
                     let value = format!("({})", values.join(", "));
                     if with_modifier {
-                        if self.ops.is_not { format!("NOT IN {}", value) } else { format!("IN {}", value) }
+                        if self.ops.is_not { Ok(format!("NOT IN {}", value)) } else { Ok(format!("IN {}", value)) }
                     } else {
-                        value
+                        Ok(value)
                     }
                 }
             },
             Json::String(json_string) => {
                 if with_modifier {
-                    if self.ops.is_not { format!("!= '{}'", json_string) } else { format!("= '{}'", json_string) }
+                    if self.ops.is_not { Ok(format!("!= '{}'", json_string)) } else { Ok(format!("= '{}'", json_string)) }
                 } else {
-                    format!("'{}'", json_string)
+                    Ok(format!("'{}'", json_string))
                 }
             },
             Json::Number(json_number) => {
                 if with_modifier {
-                    if self.ops.is_not { format!("!= {}", json_number) } else { format!("= {}", json_number) }
+                    if self.ops.is_not { Ok(format!("!= {}", json_number)) } else { Ok(format!("= {}", json_number)) }
                 } else {
-                    format!("{}", json_number)
+                    Ok(format!("{}", json_number))
                 }
             },
             Json::Bool(json_bool) => {
                 let value = if *json_bool {1} else {0};
                 if with_modifier {
-                    if self.ops.is_not { format!("!= {}", value) } else { format!("= {}", value) }
+                    if self.ops.is_not { Ok(format!("!= {}", value)) } else { Ok(format!("= {}", value)) }
                 } else {
-                    format!("{}", value)
+                    Ok(format!("{}", value))
                 }
             },
             Json::Null => {
                 if with_modifier {
-                    if self.ops.is_not { format!("IS NOT NULL") } else { format!("IS NULL") }
+                    if self.ops.is_not { Ok(format!("IS NOT NULL")) } else { Ok(format!("IS NULL")) }
                 } else {
-                    panic!("Error: Not Support")
+                    return Err(anyhow::anyhow!("Error: {:?} Not Support", self.json_value()))
                 }
             },
-            _ => panic!("Error: Not Support")
+            _ => return Err(anyhow::anyhow!("Error: {:?} Not Support", self.json_value()))
         }
     }
 }
@@ -198,7 +198,7 @@ mod tests {
              "active": true,
              "profile": null
          }), Ops::new(JoinType::And, false, false));
-        assert_eq!(r#where.to_sql(), "`users`.`active` = 1 AND `users`.`age` = 18 AND `users`.`gender` IN ('male', 'female') AND `users`.`name` = 'Tom' AND `users`.`profile` IS NULL AND `users`.`role` IN (1, 2)");
+        assert_eq!(r#where.to_sql().unwrap(), "`users`.`active` = 1 AND `users`.`age` = 18 AND `users`.`gender` IN ('male', 'female') AND `users`.`name` = 'Tom' AND `users`.`profile` IS NULL AND `users`.`role` IN (1, 2)");
         let r#where = Where::<User>::new(json!({
             "name": "Tom",
             "age": 18,
@@ -206,34 +206,34 @@ mod tests {
              "active": true,
              "profile": null
          }), Ops::new(JoinType::And, true, false));
-        assert_eq!(r#where.to_sql(), "`users`.`active` != 1 AND `users`.`age` != 18 AND `users`.`gender` NOT IN ('male', 'female') AND `users`.`name` != 'Tom' AND `users`.`profile` IS NOT NULL");
+        assert_eq!(r#where.to_sql().unwrap(), "`users`.`active` != 1 AND `users`.`age` != 18 AND `users`.`gender` NOT IN ('male', 'female') AND `users`.`name` != 'Tom' AND `users`.`profile` IS NOT NULL");
 
         let r#where = Where::<User>::new(json!("age > 18"), Ops::new(JoinType::And, false, false));
-        assert_eq!(r#where.to_sql(), "age > 18");
+        assert_eq!(r#where.to_sql().unwrap(), "age > 18");
 
         let r#where = Where::<User>::new(json!(["age > 18"]), Ops::new(JoinType::And, false, false));
-        assert_eq!(r#where.to_sql(), "age > 18");
+        assert_eq!(r#where.to_sql().unwrap(), "age > 18");
         let r#where = Where::<User>::new(json!(["name = ? AND age > ? AND gender in ? AND enable = ?", "Tom", 18, ["male", "female"], true]), Ops::new(JoinType::And, false, false));
-        assert_eq!(r#where.to_sql(), "name = 'Tom' AND age > 18 AND gender in ('male', 'female') AND enable = 1");
+        assert_eq!(r#where.to_sql().unwrap(), "name = 'Tom' AND age > 18 AND gender in ('male', 'female') AND enable = 1");
 
         //between
         let r#where = Where::<User>::new(json!({"age": [18, 30]}), Ops::new(JoinType::And, false, true));
-        assert_eq!(r#where.to_sql(), "`users`.`age` BETWEEN 18 AND 30");
+        assert_eq!(r#where.to_sql().unwrap(), "`users`.`age` BETWEEN 18 AND 30");
         let r#where = Where::<User>::new(json!({"age": [18, 30]}), Ops::new(JoinType::And, true, true));
-        assert_eq!(r#where.to_sql(), "`users`.`age` NOT BETWEEN 18 AND 30");
+        assert_eq!(r#where.to_sql().unwrap(), "`users`.`age` NOT BETWEEN 18 AND 30");
         let r#where = Where::<User>::new(json!(["age", 18, 30]), Ops::new(JoinType::And, false, true));
-        assert_eq!(r#where.to_sql(), "`users`.`'age'` BETWEEN 18 AND 30");
+        assert_eq!(r#where.to_sql().unwrap(), "`users`.`'age'` BETWEEN 18 AND 30");
         let r#where = Where::<User>::new(json!(["age", 18, 30]), Ops::new(JoinType::And, true, true));
-        assert_eq!(r#where.to_sql(), "`users`.`'age'` NOT BETWEEN 18 AND 30");
+        assert_eq!(r#where.to_sql().unwrap(), "`users`.`'age'` NOT BETWEEN 18 AND 30");
         // or between
         let r#where = Where::<User>::new(json!({"age": [18, 30], "name": "Tom"}), Ops::new(JoinType::Or, false, false));
-        assert_eq!(r#where.to_sql(), "(`users`.`age` IN (18, 30) OR `users`.`name` = 'Tom')");
+        assert_eq!(r#where.to_sql().unwrap(), "(`users`.`age` IN (18, 30) OR `users`.`name` = 'Tom')");
         let r#where = Where::<User>::new(json!({"age": [18, 30], "name": "Tom"}), Ops::new(JoinType::Or, true, false));
-        assert_eq!(r#where.to_sql(), "(`users`.`age` NOT IN (18, 30) OR `users`.`name` != 'Tom')");
+        assert_eq!(r#where.to_sql().unwrap(), "(`users`.`age` NOT IN (18, 30) OR `users`.`name` != 'Tom')");
         let r#where = Where::<User>::new(json!({"age": [18, 30], "name": "Tom"}), Ops::new(JoinType::Or, true, true));
-        assert_eq!(r#where.to_sql(), "(`users`.`age` NOT BETWEEN 18 AND 30 OR `users`.`name` != 'Tom')");
+        assert_eq!(r#where.to_sql().unwrap(), "(`users`.`age` NOT BETWEEN 18 AND 30 OR `users`.`name` != 'Tom')");
         let r#where = Where::<User>::new(json!(["age", 18, 30]), Ops::new(JoinType::Or, true, true));
-        assert_eq!(r#where.to_sql(), "(`users`.`'age'` NOT BETWEEN 18 AND 30)");
+        assert_eq!(r#where.to_sql().unwrap(), "(`users`.`'age'` NOT BETWEEN 18 AND 30)");
     }
 }
 
