@@ -30,8 +30,28 @@ impl<M> UpdateManager<M> where M: ModelAble {
         self.ctx_mut().update(condition);
         self
     }
+    pub fn increment(&mut self, column_name: &str, by: isize) -> &mut Self {
+        self.ctx_mut().increment(column_name, by);
+        self
+    }
+    pub fn decrement(&mut self, column_name: &str, by: isize) -> &mut Self {
+        self.ctx_mut().decrement(column_name, by);
+        self
+    }
     pub fn r#where(&mut self, condition: Json, ops: r#where::Ops) -> &mut Self {
         self.ctx_mut().r#where(condition, ops);
         self
     }
+    pub fn order(&mut self, condition: Json) -> &mut Self {
+        self.ast.order(condition);
+        self
+    }
+    pub fn limit(&mut self, condition: usize) -> &mut Self {
+        self.ast.limit(condition);
+        self
+    }
+    pub fn offset(&mut self, condition: usize) -> &mut Self {
+        self.ast.offset(condition);
+        self
+    }
 }
\ No newline at end of file
